@@ -106,16 +106,37 @@ REST_API_VERSION_HISTORY = """
              'volume:extend_attached_volume' policy rule. Extend in reserved
              state is intentionally NOT allowed.
     * 3.43 - Support backup CRUD with metadata.
+    * 3.44 - Add attachment-complete.
+    * 3.45 - Add ``count`` field to volume, backup and snapshot list and
+             detail APIs.
+    * 3.46 - Support create volume by Nova specific image (0 size image).
+    * 3.47 - Support create volume from backup.
+    * 3.48 - Add ``shared_targets`` and ``service_uuid`` fields to volume.
+    * 3.49 - Support report backend storage state in service list.
+    * 3.50 - Add multiattach capability
+    * 3.51 - Add support for cross AZ backups.
+    * 3.52 - ``RESKEY:availability_zones`` is a reserved spec key for AZ
+             volume type, and filter volume type by ``extra_specs`` is
+             supported now.
+    * 3.53 - Add schema validation support for request body using jsonschema
+             for V2/V3 volume APIs.
+             1. Modified create volume API to accept only parameters which are
+             documented in the api-ref otherwise it will return 400 error.
+             2. Update volume API expects user to pass at least one valid
+             parameter in the request body in order to update the volume.
+             Also, additional parameters will not be allowed.
+    * 3.54 - Add ``mode`` argument to attachment-create.
+    * 3.55 - Support transfer volume with snapshots
 """
 
 # The minimum and maximum versions of the API supported
 # The default api version request is defined to be the
 # minimum version of the API supported.
-# Explicitly using /v1 or /v2 endpoints will still work
+# Explicitly using /v2 endpoints will still work
 _MIN_API_VERSION = "3.0"
-_MAX_API_VERSION = "3.43"
-_LEGACY_API_VERSION1 = "1.0"
+_MAX_API_VERSION = "3.55"
 _LEGACY_API_VERSION2 = "2.0"
+UPDATED = "2018-07-17T00:00:00Z"
 
 
 # NOTE(cyeoh): min and max versions declared as functions so we can
@@ -129,10 +150,6 @@ def max_api_version():
     return APIVersionRequest(_MAX_API_VERSION)
 
 
-def legacy_api_version1():
-    return APIVersionRequest(_LEGACY_API_VERSION1)
-
-
 def legacy_api_version2():
     return APIVersionRequest(_LEGACY_API_VERSION2)
 
