@@ -39,6 +39,7 @@ SERVICE_STATES = {
               'volume_backend_name': 'lvm1',
               'timestamp': UTC_NOW,
               'multiattach': True,
+              'online_extend_support': True,
               'uuid': 'a3a593da-7f8d-4bb7-8b4c-f2bc1e0b4824'},
     'host2': {'total_capacity_gb': 2048,
               'free_capacity_gb': 300,
@@ -50,6 +51,7 @@ SERVICE_STATES = {
               'reserved_percentage': 10,
               'volume_backend_name': 'lvm2',
               'timestamp': UTC_NOW,
+              'online_extend_support': False,
               'uuid': '4200b32b-0bf9-436c-86b2-0675f6ac218e'},
     'host3': {'total_capacity_gb': 512,
               'free_capacity_gb': 256,
