@@ -78,15 +78,21 @@ class HackingTestCase(test.TestCase):
             "# vim: et tabstop=4 shiftwidth=4 softtabstop=4",
             6, lines))
 
-    def test_no_translate_debug_logs(self):
-        self.assertEqual(1, len(list(checks.no_translate_debug_logs(
+    def test_no_translate_logs(self):
+        self.assertEqual(1, len(list(checks.no_translate_logs(
+            "LOG.audit(_('foo'))", "cinder/scheduler/foo.py"))))
+        self.assertEqual(1, len(list(checks.no_translate_logs(
             "LOG.debug(_('foo'))", "cinder/scheduler/foo.py"))))
-
-        self.assertEqual(0, len(list(checks.no_translate_debug_logs(
-            "LOG.debug('foo')", "cinder/scheduler/foo.py"))))
-
-        self.assertEqual(0, len(list(checks.no_translate_debug_logs(
+        self.assertEqual(1, len(list(checks.no_translate_logs(
+            "LOG.error(_('foo'))", "cinder/scheduler/foo.py"))))
+        self.assertEqual(1, len(list(checks.no_translate_logs(
             "LOG.info(_('foo'))", "cinder/scheduler/foo.py"))))
+        self.assertEqual(1, len(list(checks.no_translate_logs(
+            "LOG.warning(_('foo'))", "cinder/scheduler/foo.py"))))
+        self.assertEqual(1, len(list(checks.no_translate_logs(
+            "LOG.exception(_('foo'))", "cinder/scheduler/foo.py"))))
+        self.assertEqual(1, len(list(checks.no_translate_logs(
+            "LOG.critical(_('foo'))", "cinder/scheduler/foo.py"))))
 
     def test_check_explicit_underscore_import(self):
         self.assertEqual(1, len(list(checks.check_explicit_underscore_import(
@@ -105,7 +111,7 @@ class HackingTestCase(test.TestCase):
             "msg = _('My message')",
             "cinder.tests.unit/other_files.py"))))
         self.assertEqual(0, len(list(checks.check_explicit_underscore_import(
-            "from cinder.i18n import _LE, _, _LW",
+            "from cinder.i18n import _",
             "cinder.tests.unit/other_files2.py"))))
         self.assertEqual(0, len(list(checks.check_explicit_underscore_import(
             "msg = _('My message')",
@@ -120,9 +126,6 @@ class HackingTestCase(test.TestCase):
         self.assertEqual(0, len(list(checks.check_explicit_underscore_import(
             "LOG.info('My info message')",
             "cinder.tests.unit/other_files4.py"))))
-        self.assertEqual(0, len(list(checks.check_explicit_underscore_import(
-            "from cinder.i18n import _LW",
-            "cinder.tests.unit/other_files5.py"))))
         self.assertEqual(1, len(list(checks.check_explicit_underscore_import(
             "msg = _('My message')",
             "cinder.tests.unit/other_files5.py"))))
@@ -294,42 +297,6 @@ class HackingTestCase(test.TestCase):
         self.assertEqual(1, len(list(checks.no_mutable_default_args(
             "def foo (bar={}):"))))
 
-    def test_oslo_namespace_imports_check(self):
-        self.assertEqual(1, len(list(checks.check_oslo_namespace_imports(
-            "from oslo.concurrency import foo"))))
-        self.assertEqual(0, len(list(checks.check_oslo_namespace_imports(
-            "from oslo_concurrency import bar"))))
-        self.assertEqual(1, len(list(checks.check_oslo_namespace_imports(
-            "from oslo.db import foo"))))
-        self.assertEqual(0, len(list(checks.check_oslo_namespace_imports(
-            "from oslo_db import bar"))))
-        self.assertEqual(1, len(list(checks.check_oslo_namespace_imports(
-            "from oslo.config import foo"))))
-        self.assertEqual(0, len(list(checks.check_oslo_namespace_imports(
-            "from oslo_config import bar"))))
-        self.assertEqual(1, len(list(checks.check_oslo_namespace_imports(
-            "from oslo.utils import foo"))))
-        self.assertEqual(0, len(list(checks.check_oslo_namespace_imports(
-            "from oslo_utils import bar"))))
-        self.assertEqual(1, len(list(checks.check_oslo_namespace_imports(
-            "from oslo.serialization import foo"))))
-        self.assertEqual(0, len(list(checks.check_oslo_namespace_imports(
-            "from oslo_serialization import bar"))))
-        self.assertEqual(1, len(list(checks.check_oslo_namespace_imports(
-            "from oslo.log import foo"))))
-        self.assertEqual(0, len(list(checks.check_oslo_namespace_imports(
-            "from oslo_log import bar"))))
-
-    def test_no_contextlib_nested(self):
-        self.assertEqual(1, len(list(checks.check_no_contextlib_nested(
-            "with contextlib.nested("))))
-        self.assertEqual(1, len(list(checks.check_no_contextlib_nested(
-            "  with nested("))))
-        self.assertEqual(0, len(list(checks.check_no_contextlib_nested(
-            "with my.nested("))))
-        self.assertEqual(0, len(list(checks.check_no_contextlib_nested(
-            "with foo as bar"))))
-
     def test_check_datetime_now(self):
         self.assertEqual(1, len(list(checks.check_datetime_now(
             "datetime.now", False))))
@@ -346,26 +313,6 @@ class HackingTestCase(test.TestCase):
         self.assertEqual(0, len(list(checks.check_timeutils_strtime(
             "strftime"))))
 
-    def test_validate_log_translations(self):
-        self.assertEqual(1, len(list(checks.validate_log_translations(
-            "LOG.info('foo')", "foo.py"))))
-        self.assertEqual(1, len(list(checks.validate_log_translations(
-            "LOG.warning('foo')", "foo.py"))))
-        self.assertEqual(1, len(list(checks.validate_log_translations(
-            "LOG.error('foo')", "foo.py"))))
-        self.assertEqual(1, len(list(checks.validate_log_translations(
-            "LOG.exception('foo')", "foo.py"))))
-        self.assertEqual(0, len(list(checks.validate_log_translations(
-            "LOG.info('foo')", "cinder/tests/foo.py"))))
-        self.assertEqual(0, len(list(checks.validate_log_translations(
-            "LOG.info(_LI('foo')", "foo.py"))))
-        self.assertEqual(0, len(list(checks.validate_log_translations(
-            "LOG.warning(_LW('foo')", "foo.py"))))
-        self.assertEqual(0, len(list(checks.validate_log_translations(
-            "LOG.error(_LE('foo')", "foo.py"))))
-        self.assertEqual(0, len(list(checks.validate_log_translations(
-            "LOG.exception(_LE('foo')", "foo.py"))))
-
     def test_check_unicode_usage(self):
         self.assertEqual(1, len(list(checks.check_unicode_usage(
             "unicode(msg)", False))))
@@ -420,13 +367,6 @@ class HackingTestCase(test.TestCase):
         self.assertEqual(0, len(list(checks.dict_constructor_with_list_copy(
             "      self._render_dict(xml, data_el, data.__dict__)"))))
 
-    def test_validate_assertIsNone(self):
-        test_value = None
-        self.assertEqual(0, len(list(checks.validate_assertIsNone(
-            "assertIsNone(None)"))))
-        self.assertEqual(1, len(list(checks.validate_assertIsNone(
-            "assertEqual(None, %s)" % test_value))))
-
     def test_validate_assertTrue(self):
         test_value = True
         self.assertEqual(0, len(list(checks.validate_assertTrue(
@@ -443,8 +383,7 @@ class HackingTestCase(test.TestCase):
         (1, 'LOG.debug', "cinder/tests/fake.py", False),
         (0, 'LOG.info.assert_called_once_with', "cinder/tests/fake.py", False),
         (0, 'some.LOG.error.call', "cinder/tests/fake.py", False),
-        (0, 'LOG.warning', "cinder/tests/unit/fake.py", True),
-        (0, 'LOG.warning', "cinder/tests/unit/integrated/fake.py", False))
+        (0, 'LOG.warning', "cinder/tests/unit/fake.py", True))
     def test_no_test_log(self, first, second, third, fourth):
         self.assertEqual(first, len(list(checks.no_test_log(
             "%s('arg')" % second, third, fourth))))
