@@ -38,6 +38,7 @@ from cinder.volume import qos_specs
 from cinder.volume import volume_types
 
 
+@ddt.ddt
 class NetAppDriverUtilsTestCase(test.TestCase):
 
     @mock.patch.object(na_utils, 'LOG', mock.Mock())
@@ -121,7 +122,7 @@ class NetAppDriverUtilsTestCase(test.TestCase):
 
         actual_properties = na_utils.get_iscsi_connection_properties(
             fake.ISCSI_FAKE_LUN_ID, fake.ISCSI_FAKE_VOLUME,
-            fake.ISCSI_FAKE_IQN, fake.ISCSI_FAKE_ADDRESS,
+            fake.ISCSI_FAKE_IQN, fake.ISCSI_FAKE_ADDRESS_IPV4,
             fake.ISCSI_FAKE_PORT)
 
         actual_properties_mapped = actual_properties['data']
@@ -134,7 +135,7 @@ class NetAppDriverUtilsTestCase(test.TestCase):
 
         actual_properties = na_utils.get_iscsi_connection_properties(
             FAKE_LUN_ID, fake.ISCSI_FAKE_VOLUME, fake.ISCSI_FAKE_IQN,
-            fake.ISCSI_FAKE_ADDRESS, fake.ISCSI_FAKE_PORT)
+            fake.ISCSI_FAKE_ADDRESS_IPV4, fake.ISCSI_FAKE_PORT)
 
         actual_properties_mapped = actual_properties['data']
 
@@ -145,9 +146,17 @@ class NetAppDriverUtilsTestCase(test.TestCase):
 
         self.assertRaises(TypeError, na_utils.get_iscsi_connection_properties,
                           FAKE_LUN_ID, fake.ISCSI_FAKE_VOLUME,
-                          fake.ISCSI_FAKE_IQN, fake.ISCSI_FAKE_ADDRESS,
+                          fake.ISCSI_FAKE_IQN, fake.ISCSI_FAKE_ADDRESS_IPV4,
                           fake.ISCSI_FAKE_PORT)
 
+    def test_iscsi_connection_properties_ipv6(self):
+        actual_properties = na_utils.get_iscsi_connection_properties(
+            '1', fake.ISCSI_FAKE_VOLUME_NO_AUTH, fake.ISCSI_FAKE_IQN,
+            fake.ISCSI_FAKE_ADDRESS_IPV6, fake.ISCSI_FAKE_PORT)
+
+        self.assertDictEqual(actual_properties['data'],
+                             fake.FC_ISCSI_TARGET_INFO_DICT_IPV6)
+
     def test_get_volume_extra_specs(self):
         fake_extra_specs = {'fake_key': 'fake_value'}
         fake_volume_type = {'extra_specs': fake_extra_specs}
@@ -538,6 +547,29 @@ class NetAppDriverUtilsTestCase(test.TestCase):
 
         self.assertIsNone(result)
 
+    @ddt.data(("192.168.99.24:/fake/export/path", "192.168.99.24",
+               "/fake/export/path"),
+              ("127.0.0.1:/", "127.0.0.1", "/"),
+              ("[f180::30d9]:/path_to-export/3.1/this folder", "f180::30d9",
+               "/path_to-export/3.1/this folder"),
+              ("[::]:/", "::", "/"),
+              ("[2001:db8::1]:/fake_export", "2001:db8::1", "/fake_export"))
+    @ddt.unpack
+    def test_get_export_host_junction_path(self, share, host, junction_path):
+        result_host, result_path = na_utils.get_export_host_junction_path(
+            share)
+
+        self.assertEqual(host, result_host)
+        self.assertEqual(junction_path, result_path)
+
+    @ddt.data("192.14.21.0/wrong_export", "192.14.21.0:8080:/wrong_export"
+              "2001:db8::1:/wrong_export",
+              "[2001:db8::1:/wrong_export", "2001:db8::1]:/wrong_export")
+    def test_get_export_host_junction_path_with_invalid_exports(self, share):
+        self.assertRaises(exception.NetAppDriverException,
+                          na_utils.get_export_host_junction_path,
+                          share)
+
 
 class OpenStackInfoTestCase(test.TestCase):
 
