@@ -61,6 +61,7 @@ class CommonAdapter(replication.ReplicationAdapter):
         self.allowed_ports = None
         self.force_delete_lun_in_sg = None
         self.max_over_subscription_ratio = None
+        self.max_luns_per_storage_group = None
         self.ignore_pool_full_threshold = None
         self.reserved_percentage = None
         self.destroy_empty_sg = None
@@ -81,6 +82,8 @@ class CommonAdapter(replication.ReplicationAdapter):
         self._normalize_config()
         self.client = self._build_client_from_config(
             self.config, self.queue_path)
+        self.client.set_max_luns_per_sg(
+            self.config.max_luns_per_storage_group)
         # Replication related
         if (self.active_backend_id in
                 common.ReplicationDeviceList.get_backend_ids(self.config)):
@@ -815,6 +818,11 @@ class CommonAdapter(replication.ReplicationAdapter):
         """Deletes a snapshot."""
         self.client.delete_snapshot(snapshot.name)
 
+    def restore_snapshot(self, volume, snapshot):
+        """Restores a snapshot."""
+        lun_id = self.client.get_lun_id(volume)
+        self.client.restore_snapshot(lun_id, snapshot.name)
+
     def _get_referenced_lun(self, existing_ref):
         lun = None
         if 'source-id' in existing_ref:
