@@ -173,29 +173,18 @@ def log_extra_spec_warnings(extra_specs):
                                  'new': DEPRECATED_SSC_SPECS[spec]})
 
 
-def get_iscsi_connection_properties(lun_id, volume, iqns,
-                                    addresses, ports):
+def get_iscsi_connection_properties(lun_id, volume, iqn,
+                                    address, port):
     # literal ipv6 address
-    addresses = [netutils.escape_ipv6(a) if netutils.is_valid_ipv6(a) else a
-                 for a in addresses]
-
-    lun_id = int(lun_id)
-    if isinstance(iqns, six.string_types):
-        iqns = [iqns] * len(addresses)
-
-    target_portals = ['%s:%s' % (a, p) for a, p in zip(addresses, ports)]
+    if netutils.is_valid_ipv6(address):
+        address = netutils.escape_ipv6(address)
 
     properties = {}
     properties['target_discovered'] = False
-    properties['target_portal'] = target_portals[0]
-    properties['target_iqn'] = iqns[0]
-    properties['target_lun'] = lun_id
+    properties['target_portal'] = '%s:%s' % (address, port)
+    properties['target_iqn'] = iqn
+    properties['target_lun'] = int(lun_id)
     properties['volume_id'] = volume['id']
-    if len(addresses) > 1:
-        properties['target_portals'] = target_portals
-        properties['target_iqns'] = iqns
-        properties['target_luns'] = [lun_id] * len(addresses)
-
     auth = volume['provider_auth']
     if auth:
         (auth_method, auth_username, auth_secret) = auth.split()
@@ -298,7 +287,7 @@ def get_pool_name_filter_regex(configuration):
     # If the configuration parameter is specified as an empty string
     # (interpreted as matching all pools), we replace it here with
     # (.+) to be explicit with CSV compatibility support implemented below.
-    pool_patterns = configuration.netapp_pool_name_search_pattern or '(.+)'
+    pool_patterns = configuration.netapp_pool_name_search_pattern or r'(.+)'
 
     # Strip whitespace from start/end and then 'or' all regex patterns
     pool_patterns = '|'.join(['^' + pool_pattern.strip('^$ \t') + '$' for
