@@ -17,10 +17,10 @@ Volume driver for QNAP Storage.
 This driver supports QNAP Storage for iSCSI.
 """
 import base64
+from collections import OrderedDict
 import eventlet
 import functools
 import re
-import ssl
 import threading
 import time
 
@@ -31,8 +31,8 @@ from oslo_log import log as logging
 from oslo_utils import strutils
 from oslo_utils import timeutils
 from oslo_utils import units
+import requests
 import six
-from six.moves import http_client
 from six.moves import urllib
 
 from cinder import exception
@@ -46,12 +46,13 @@ LOG = logging.getLogger(__name__)
 
 qnap_opts = [
     cfg.URIOpt('qnap_management_url',
-               help='The URL to management QNAP Storage'),
+               help='The URL to management QNAP Storage. '
+                    'Driver does not support IPv6 address in URL.'),
     cfg.StrOpt('qnap_poolname',
                help='The pool name in the QNAP Storage'),
     cfg.StrOpt('qnap_storage_protocol',
                default='iscsi',
-               help='Communication protocol to access QNAP storage'),
+               help='Communication protocol to access QNAP storage')
 ]
 
 CONF = cfg.CONF
@@ -62,23 +63,27 @@ CONF.register_opts(qnap_opts, group=configuration.SHARED_CONF_GROUP)
 class QnapISCSIDriver(san.SanISCSIDriver):
     """QNAP iSCSI based cinder driver
 
-      .. code-block:: default
+    .. code-block:: default
 
-        Version History:
-          1.0.0:
-                Initial driver (Only iSCSI).
-          1.2.001:
-                Add supports for Thin Provisioning, SSD Cache, Deduplication
-                , Compression and CHAP.
-          1.2.002:
-                Add support for QES fw 2.0.0.
+      Version History:
+        1.0.0:
+              Initial driver (Only iSCSI).
+        1.2.001:
+              Add supports for Thin Provisioning, SSD Cache, Deduplication,
+              Compression and CHAP.
+        1.2.002:
+              Add support for QES fw 2.0.0.
+        1.2.003:
+              Add support for QES fw 2.1.0.
 
+    NOTE: Set driver_ssl_cert_verify as True under backend section to
+          enable SSL verification.
     """
 
     # ThirdPartySystems wiki page
     CI_WIKI_NAME = "QNAP_CI"
 
-    VERSION = '1.2.002'
+    VERSION = '1.2.003'
 
     TIME_INTERVAL = 3
 
@@ -151,7 +156,8 @@ class QnapISCSIDriver(san.SanISCSIDriver):
         self.api_executor = QnapAPIExecutor(
             username=self.configuration.san_login,
             password=self.configuration.san_password,
-            management_url=self.configuration.qnap_management_url)
+            management_url=self.configuration.qnap_management_url,
+            verify_ssl=self.configuration.driver_ssl_cert_verify)
 
         nas_model_name, internal_model_name, fw_version = (
             self.api_executor.get_basic_info(
@@ -189,7 +195,8 @@ class QnapISCSIDriver(san.SanISCSIDriver):
                 return (QnapAPIExecutorTS(
                     username=self.configuration.san_login,
                     password=self.configuration.san_password,
-                    management_url=self.configuration.qnap_management_url))
+                    management_url=self.configuration.qnap_management_url,
+                    verify_ssl=self.configuration.driver_ssl_cert_verify))
         elif model_type in tes_model_types:
             if 'TS' in internal_model_name:
                 if (fw_version >= "4.2") and (fw_version <= "4.4"):
@@ -201,20 +208,23 @@ class QnapISCSIDriver(san.SanISCSIDriver):
                     return (QnapAPIExecutorTS(
                         username=self.configuration.san_login,
                         password=self.configuration.san_password,
-                        management_url=self.configuration.qnap_management_url))
-            elif "1.1.2" <= fw_version <= "2.0.9999":
+                        management_url=self.configuration.qnap_management_url,
+                        verify_ssl=self.configuration.driver_ssl_cert_verify))
+            elif "1.1.2" <= fw_version <= "2.1.9999":
                 LOG.debug('Create TES API Executor')
                 return (QnapAPIExecutorTES(
                     username=self.configuration.san_login,
                     password=self.configuration.san_password,
-                    management_url=self.configuration.qnap_management_url))
+                    management_url=self.configuration.qnap_management_url,
+                    verify_ssl=self.configuration.driver_ssl_cert_verify))
         elif model_type in es_model_types:
-            if "1.1.2" <= fw_version <= "2.0.9999":
+            if "1.1.2" <= fw_version <= "2.1.9999":
                 LOG.debug('Create ES API Executor')
                 return (QnapAPIExecutor(
                     username=self.configuration.san_login,
                     password=self.configuration.san_password,
-                    management_url=self.configuration.qnap_management_url))
+                    management_url=self.configuration.qnap_management_url,
+                    verify_ssl=self.configuration.driver_ssl_cert_verify))
 
         msg = _('Model not support')
         raise exception.VolumeDriverException(message=msg)
@@ -326,12 +336,13 @@ class QnapISCSIDriver(san.SanISCSIDriver):
         while True:
             created_lun = self.api_executor.get_lun_info(
                 LUNIndex=create_lun_index)
-            if created_lun.find('LUNNAA') is not None:
+            if (created_lun is not None and
+                    created_lun.find('LUNNAA').text is not None):
                 lun_naa = created_lun.find('LUNNAA').text
 
             try_times = try_times + 3
             eventlet.sleep(self.TIME_INTERVAL)
-            if(try_times > max_wait_sec or lun_naa is not None):
+            if(try_times > max_wait_sec or lun_naa != ""):
                 break
 
         LOG.debug('LUNNAA: %s', lun_naa)
@@ -382,7 +393,7 @@ class QnapISCSIDriver(san.SanISCSIDriver):
                 LOG.debug('in ES FW before 1.1.2/1.1.3: get_lun_info')
                 del_lun = self.api_executor.get_lun_info(
                     LUNIndex=lun_index)
-            elif "1.1.4" <= fw_version <= "2.0.9999":
+            elif "1.1.4" <= fw_version <= "2.1.9999":
                 LOG.debug('in ES FW after 1.1.4: get_one_lun_info')
                 ret = self.api_executor.get_one_lun_info(lun_index)
                 del_lun = (ET.fromstring(ret['data']).find('LUNInfo')
@@ -502,14 +513,15 @@ class QnapISCSIDriver(san.SanISCSIDriver):
         while True:
             created_lun = self.api_executor.get_lun_info(
                 LUNName=cloned_lun_name)
-            if created_lun.find('LUNNAA') is not None:
+            if (created_lun is not None and
+                    created_lun.find('LUNNAA') is not None):
                 lun_naa = created_lun.find('LUNNAA').text
                 lun_index = created_lun.find('LUNIndex').text
                 LOG.debug('LUNIndex: %s', lun_index)
 
             try_times = try_times + 3
             eventlet.sleep(self.TIME_INTERVAL)
-            if(try_times > max_wait_sec or lun_naa is not None):
+            if(try_times > max_wait_sec or lun_naa != ""):
                 break
 
         LOG.debug('LUNNAA: %s', lun_naa)
@@ -556,12 +568,13 @@ class QnapISCSIDriver(san.SanISCSIDriver):
         while True:
             created_snapshot = self.api_executor.get_snapshot_info(
                 lun_index=lun_index, snapshot_name=create_snapshot_name)
-            if created_snapshot is not None:
+            if (created_snapshot is not None and
+                    created_snapshot.find('snapshot_id').text is not None):
                 snapshot_id = created_snapshot.find('snapshot_id').text
 
             try_times = try_times + 3
             eventlet.sleep(self.TIME_INTERVAL)
-            if(try_times > max_wait_sec or created_snapshot is not None):
+            if(try_times > max_wait_sec or snapshot_id != ""):
                 break
 
         LOG.debug('created_snapshot: %s', created_snapshot)
@@ -613,14 +626,16 @@ class QnapISCSIDriver(san.SanISCSIDriver):
         while True:
             created_lun = self.api_executor.get_lun_info(
                 LUNName=create_lun_name)
-            if created_lun.find('LUNNAA') is not None:
+            if (created_lun is not None and
+                    created_lun.find('LUNNAA') is not None):
                 lun_naa = created_lun.find('LUNNAA').text
                 lun_index = created_lun.find('LUNIndex').text
+                LOG.debug('LUNNAA: %s', lun_naa)
                 LOG.debug('LUNIndex: %s', lun_index)
 
             try_times = try_times + 3
             eventlet.sleep(self.TIME_INTERVAL)
-            if(try_times > max_wait_sec or lun_naa is not None):
+            if(try_times > max_wait_sec or lun_naa != ""):
                 break
 
         if (volume['size'] > snapshot['volume_size']):
@@ -817,7 +832,7 @@ class QnapISCSIDriver(san.SanISCSIDriver):
                 LOG.debug('in ES FW before 1.1.2/1.1.3: get_lun_info')
                 selected_lun = self.api_executor.get_lun_info(
                     LUNNAA=lun_naa)
-            elif "1.1.4" <= fw_version <= "2.0.9999":
+            elif "1.1.4" <= fw_version <= "2.1.9999":
                 LOG.debug('in ES FW after 1.1.4: get_one_lun_info')
                 ret = self.api_executor.get_one_lun_info(lun_index)
                 selected_lun = (ET.fromstring(ret['data']).find('LUNInfo')
@@ -870,7 +885,7 @@ class QnapISCSIDriver(san.SanISCSIDriver):
                     eventlet.sleep(self.TIME_INTERVAL)
                     if(try_times > max_wait_sec or LUNNumber != ""):
                         break
-                elif "1.1.4" <= fw_version <= "2.0.9999":
+                elif "1.1.4" <= fw_version <= "2.1.9999":
                     LOG.debug('in ES FW after 1.1.4: get_one_lun_info')
                     ret = self.api_executor.get_one_lun_info(lun_index)
                     root = ET.fromstring(ret['data'])
@@ -1016,7 +1031,7 @@ class QnapISCSIDriver(san.SanISCSIDriver):
                 LOG.debug('in ES FW before 1.1.2/1.1.3: get_lun_info')
                 selected_lun = self.api_executor.get_lun_info(
                     LUNIndex=lun_index)
-            elif "1.1.4" <= fw_version <= "2.0.9999":
+            elif "1.1.4" <= fw_version <= "2.1.9999":
                 LOG.debug('in ES FW after 1.1.4: get_one_lun_info')
                 ret = self.api_executor.get_one_lun_info(lun_index)
                 selected_lun = (ET.fromstring(ret['data']).find('LUNInfo')
@@ -1070,10 +1085,13 @@ class QnapISCSIDriver(san.SanISCSIDriver):
 
     @utils.synchronized('_attach_volume')
     def _detach_volume(self, context, attach_info, volume, properties,
-                       force=False, remote=False):
-        super(QnapISCSIDriver, self)._detach_volume(context, attach_info,
-                                                    volume, properties,
-                                                    force, remote)
+                       force=False, remote=False, ignore_errors=False):
+        super(QnapISCSIDriver, self)._detach_volume(
+            context, attach_info,
+            volume, properties,
+            force=force, remote=remote,
+            ignore_errors=ignore_errors
+        )
 
     @utils.synchronized('_attach_volume')
     def _attach_volume(self, context, volume, properties, remote=False):
@@ -1118,9 +1136,15 @@ class QnapAPIExecutor(object):
         self.password = kwargs['password']
         self.ip, self.port, self.ssl = (
             self._parse_management_url(kwargs['management_url']))
+        self.verify_ssl = kwargs['verify_ssl']
         self._login()
 
     def _parse_management_url(self, management_url):
+        # NOTE(Ibad): This parser isn't compatible with IPv6 address.
+        # Typical IPv6 address will have : as delimiters and
+        # URL is represented as https://[3ffe:2a00:100:7031::1]:8080
+        # since the regular expression below uses : to identify ip and port
+        # it won't work with IPv6 address.
         pattern = re.compile(r"(http|https)\:\/\/(\S+)\:(\d+)")
         matches = pattern.match(management_url)
         if matches.group(1) == 'http':
@@ -1135,23 +1159,10 @@ class QnapAPIExecutor(object):
         """Get the basic information of NAS."""
         management_ip, management_port, management_ssl = (
             self._parse_management_url(management_url))
-        connection = None
-        if management_ssl:
-            if hasattr(ssl, '_create_unverified_context'):
-                context = ssl._create_unverified_context()
-                connection = http_client.HTTPSConnection(management_ip,
-                                                         port=management_port,
-                                                         context=context)
-            else:
-                connection = http_client.HTTPSConnection(management_ip,
-                                                         port=management_port)
-        else:
-            connection = (
-                http_client.HTTPConnection(management_ip, management_port))
 
-        connection.request('GET', '/cgi-bin/authLogin.cgi')
-        response = connection.getresponse()
-        data = response.read()
+        response = self._get_response(management_ip, management_port,
+                                      management_ssl, '/cgi-bin/authLogin.cgi')
+        data = response.text
 
         root = ET.fromstring(data)
 
@@ -1161,6 +1172,29 @@ class QnapAPIExecutor(object):
 
         return nas_model_name, internal_model_name, fw_version
 
+    def _get_response(self, host_ip, host_port, use_ssl, action, body=None):
+        """"Execute http request and return response."""
+        method = 'GET'
+        headers = None
+        protocol = 'https' if use_ssl else 'http'
+        verify = self.verify_ssl if use_ssl else False
+        # NOTE(ibad): URL formed here isn't IPv6 compatible
+        # we should surround host ip with [] when IPv6 is supported
+        # so the final URL can be like https://[3ffe:2a00:100:7031::1]:8080
+        url = '%s://%s:%s%s' % (protocol, host_ip, host_port, action)
+
+        if body:
+            method = 'POST'
+            headers = {
+                'Content-Type': 'application/x-www-form-urlencoded',
+                'charset': 'utf-8'
+            }
+
+        response = requests.request(method, url, data=body, headers=headers,
+                                    verify=verify)
+
+        return response
+
     def _execute_and_get_response_details(self, nas_ip, url, post_parm=None):
         """Will prepare response after executing an http request."""
         LOG.debug('_execute_and_get_response_details url: %s', url)
@@ -1168,63 +1202,33 @@ class QnapAPIExecutor(object):
 
         res_details = {}
 
-        start_time1 = time.time()
-
-        # Prepare the connection
-        if self.ssl:
-            if hasattr(ssl, '_create_unverified_context'):
-                context = ssl._create_unverified_context()
-                connection = http_client.HTTPSConnection(nas_ip,
-                                                         port=self.port,
-                                                         context=context)
-            else:
-                connection = http_client.HTTPSConnection(
-                    nas_ip, port=self.port)
-        else:
-            connection = http_client.HTTPConnection(nas_ip, self.port)
-
-        elapsed_time1 = time.time() - start_time1
-        LOG.debug('connection elapsed_time: %s', elapsed_time1)
-
-        start_time2 = time.time()
-
         # Make the connection
-        if post_parm is None:
-            connection.request('GET', url)
-        else:
-            headers = {
-                "Content-Type": "application/x-www-form-urlencoded",
-                "charset": "utf-8"}
-            connection.request('POST', url, post_parm, headers)
-
+        start_time2 = time.time()
+        response = self._get_response(
+            nas_ip, self.port, self.ssl, url, post_parm)
         elapsed_time2 = time.time() - start_time2
         LOG.debug('request elapsed_time: %s', elapsed_time2)
 
-        # Extract the response as the connection was successful
-        start_time = time.time()
-        response = connection.getresponse()
-        elapsed_time = time.time() - start_time
-        LOG.debug('cgi elapsed_time: %s', elapsed_time)
         # Read the response
-        data = response.read()
-        LOG.debug('response status: %s', response.status)
+        data = response.text
+        LOG.debug('response status: %s', response.status_code)
+
         # Extract http error msg if any
         error_details = None
         res_details['data'] = data
         res_details['error'] = error_details
-        res_details['http_status'] = response.status
+        res_details['http_status'] = response.status_code
 
-        connection.close()
         return res_details
 
     def execute_login(self):
         """Login and return sid."""
-        params = {}
-        params['user'] = self.username
+        params = OrderedDict()
         params['pwd'] = base64.b64encode(self.password.encode("utf-8"))
         params['serviceKey'] = '1'
+        params['user'] = self.username
 
-        sanitized_params = {}
+        sanitized_params = OrderedDict()
 
         for key in params:
             value = params[key]
@@ -1247,14 +1251,17 @@ class QnapAPIExecutor(object):
         self.sid = self.execute_login()
 
     def _get_res_details(self, url, **kwargs):
-        sanitized_params = {}
+        sanitized_params = OrderedDict()
 
-        for key, value in kwargs.items():
+        # Sort the dict of parameters
+        params = utils.create_ordereddict(kwargs)
+
+        for key, value in params.items():
             if value is not None:
                 sanitized_params[key] = six.text_type(value)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
-        url = url + sanitized_params
+        encoded_params = urllib.parse.urlencode(sanitized_params)
+        url = url + encoded_params
 
         res_details = self._execute_and_get_response_details(self.ip, url)
 
