@@ -98,6 +98,8 @@ class OnFailureRescheduleTask(flow_utils.CinderTask):
             exception.VolumeTypeNotFound,
             exception.ImageUnacceptable,
             exception.ImageTooBig,
+            exception.InvalidSignatureImage,
+            exception.ImageSignatureVerificationException
         ]
 
     def execute(self, **kwargs):
@@ -536,10 +538,10 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
                           {'volume_id': volume.id})
             raise exception.ImageUnacceptable(ex)
         except exception.ImageTooBig as ex:
-            LOG.exception("Failed to copy image %(image_id)s to volume: "
-                          "%(volume_id)s",
-                          {'volume_id': volume.id, 'image_id': image_id})
-            excutils.save_and_reraise_exception()
+            with excutils.save_and_reraise_exception():
+                LOG.exception("Failed to copy image %(image_id)s to volume: "
+                              "%(volume_id)s",
+                              {'volume_id': volume.id, 'image_id': image_id})
         except Exception as ex:
             LOG.exception("Failed to copy image %(image_id)s to "
                           "volume: %(volume_id)s",
@@ -709,6 +711,10 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
         except NotImplementedError:
             LOG.warning('Backend does not support creating image-volume '
                         'clone. Image will be downloaded from Glance.')
+        except exception.CinderException as e:
+            LOG.warning('Failed to create volume from image-volume cache, '
+                        'image will be downloaded from Glance. Error: '
+                        '%(exception)s', {'exception': e})
         return None, False
 
     @coordination.synchronized('{image_id}')
@@ -781,25 +787,13 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
                 LOG.info('Unable to get Cinder internal context, will '
                          'not use image-volume cache.')
             else:
-                try:
-                    model_update, cloned = self._create_from_image_cache(
-                        context,
-                        internal_context,
-                        volume,
-                        image_id,
-                        image_meta
-                    )
-                except exception.CinderException as e:
-                    LOG.warning('Failed to create volume from image-volume '
-                                'cache, image will be downloaded from Glance. '
-                                'Error: %(exception)s',
-                                {'exception': e})
-
-                    # If an exception occurred when cloning the image-volume,
-                    # it may be the image-volume reached its snapshot limit.
-                    # Create another "fresh" cache entry.
-                    update_cache = True
-
+                model_update, cloned = self._create_from_image_cache(
+                    context,
+                    internal_context,
+                    volume,
+                    image_id,
+                    image_meta
+                )
                 # Don't cache unless directed.
                 if not cloned and update_cache:
                     should_create_cache_entry = True
@@ -818,6 +812,17 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
                     with image_utils.TemporaryImages.fetch(
                             image_service, context, image_id,
                             backend_name) as tmp_image:
+                        if CONF.verify_glance_signatures != 'disabled':
+                            # Verify image signature via reading content from
+                            # temp image, and store the verification flag if
+                            # required.
+                            verified = \
+                                image_utils.verify_glance_image_signature(
+                                    context, image_service,
+                                    image_id, tmp_image)
+                            self.db.volume_glance_metadata_bulk_create(
+                                context, volume.id,
+                                {'signature_verified': verified})
                         # Try to create the volume as the minimal size,
                         # then we can extend once the image has been
                         # downloaded.
@@ -846,6 +851,15 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
                             detail=
                             message_field.Detail.NOT_ENOUGH_SPACE_FOR_IMAGE,
                             exception=e)
+                except exception.ImageSignatureVerificationException as err:
+                    with excutils.save_and_reraise_exception():
+                        self.message.create(
+                            context,
+                            message_field.Action.COPY_IMAGE_TO_VOLUME,
+                            resource_uuid=volume.id,
+                            detail=
+                            message_field.Detail.SIGNATURE_VERIFICATION_FAILED,
+                            exception=err)
 
             if should_create_cache_entry:
                 # Update the newly created volume db entry before we clone it
@@ -958,7 +972,6 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
                      "backup service to restore the volume with backup.",
                      {'id': backup_id})
             model_update = self._create_raw_volume(volume, **kwargs) or {}
-            model_update.update({'status': 'restoring-backup'})
             volume.update(model_update)
             volume.save()
 
